# Footer

A document footer.

**Type:** object

## Properties

- **footerId** (string): The ID of the footer.
- **content** (array of [StructuralElement](structuralelement.md)): The contents of the footer. The indexes for a footer's content begin at zero.
